==> bootstrap_like_grid-0.0.1.tar.gz: lib/src/bs_column.dart <==
import 'package:flutter/material.dart';
import 'package:bootstrap_like_grid/src/bs_break_points.dart';
import 'package:bootstrap_like_grid/src/bs_column_state.dart';
import 'package:bootstrap_like_grid/src/wrappers/bs_container_wrapper.dart';

/// A column for widgets, must be a child of a BSContainer, and should be the child of a BSRow.
class BSColumn extends StatefulWidget {
  /// children of column, can be almost anything
  final List<Widget> children;

  /// breakpoints, only.
  /// case sensitive
  /// num: 0-12
  /// col
  /// col-num
  /// col-sm-num
  /// col-md-num
  /// col-lg-num
  /// col-xl-num
  /// col-xxl-num
  final List<String> breakPointTriggers;

  final CrossAxisAlignment crossAxisAlignment;
  final MainAxisAlignment mainAxisAlignment;
  final MainAxisSize mainAxisSize;
  final TextDirection? textDirection;
  final TextBaseline? textBaseline;
  final VerticalDirection verticalDirection;
  final double? height;

  const BSColumn({
    Key? key,
    required this.children,
    this.breakPointTriggers = const ["col-12"],
    this.crossAxisAlignment = CrossAxisAlignment.start,
    this.mainAxisAlignment = MainAxisAlignment.start,
    this.mainAxisSize = MainAxisSize.max,
    this.textDirection,
    this.textBaseline,
    this.verticalDirection = VerticalDirection.down,
    this.height,
  }) : super(key: key);

  @override
  _BSColumnState createState() {
    return _BSColumnState();
  }
}

class _BSColumnState extends BSColumnState<BSColumn> {
  final String _regExpression = r"(^col$)|(^col-)(([0-9]|([1-9][0-2]))|((sm)|(md)|(lg)|(xl)|(xxl))-([0-9]|([1-9][0-2])))$";

  @override
  void initState() {
    super.initState();
    RegExp regExp = RegExp(
      _regExpression,
      caseSensitive: false,
      multiLine: false,
      dotAll: false,
    );

    // ensure that passed breakpoints are valid
    for (int i = 0; i < widget.breakPointTriggers.length; i++) {
      if (regExp.firstMatch(widget.breakPointTriggers[i]) == null) {
        throw FormatException("Must pass valid break point triggers only. Ex: 'col', 'col-0', 'col-12', 'col-xxl-6'.\nMust match the reg expression (case sensitive):\n$_regExpression\nPassed Value: ${widget.breakPointTriggers[i]}");
      }
    }
  }

  /// returns set breakpoint triggers
  List<String> getBreakPointTriggers() {
    return widget.breakPointTriggers;
  }

  @override
  Widget build(BuildContext context) {
    double maxWidth = BSContainerWrapper.of(context).width;
    double width = BSBreakPoints.columnWidthFromBreakPointTriggers(
      maxWidth: maxWidth,
      screenWidth: MediaQuery.of(context).size.width,
      breakPointTriggers: widget.breakPointTriggers,
    );

    return SizedBox(
      width: width,
      height: widget.height,
      child: Column(
        crossAxisAlignment: widget.crossAxisAlignment,
        mainAxisAlignment: widget.mainAxisAlignment,
        mainAxisSize: widget.mainAxisSize,
        textDirection: widget.textDirection,
        textBaseline: widget.textBaseline,
        verticalDirection: widget.verticalDirection,
        children: widget.children,
      ),
    );
  }
}

==> bootstrap_like_grid-0.0.2.tar.gz: lib/src/bs_column.dart <==
import 'package:flutter/material.dart';
import 'package:bootstrap_like_grid/src/bs_break_points.dart';
import 'package:bootstrap_like_grid/src/bs_column_state.dart';
import 'package:bootstrap_like_grid/src/wrappers/bs_container_wrapper.dart';

/// A column for widgets, must be a child of a BSContainer, and should be the child of a BSRow.
class BSColumn extends StatefulWidget {
  /// children of column, can be almost anything
  final List<Widget> children;

  /// breakpoints, only.
  /// case sensitive
  /// num: 0-12
  /// col
  /// col-num
  /// col-sm-num
  /// col-md-num
  /// col-lg-num
  /// col-xl-num
  /// col-xxl-num
  final List<String> breakPointTriggers;

  final CrossAxisAlignment crossAxisAlignment;
  final MainAxisAlignment mainAxisAlignment;
  final MainAxisSize mainAxisSize;
  final TextDirection? textDirection;
  final TextBaseline? textBaseline;
  final VerticalDirection verticalDirection;
  final double? height;

  const BSColumn({
    Key? key,
    required this.children,
    this.breakPointTriggers = const ["col-12"],
    this.crossAxisAlignment = CrossAxisAlignment.start,
    this.mainAxisAlignment = MainAxisAlignment.start,
    this.mainAxisSize = MainAxisSize.max,
    this.textDirection,
    this.textBaseline,
    this.verticalDirection = VerticalDirection.down,
    this.height,
  }) : super(key: key);

  @override
  _BSColumnState createState() {
    return _BSColumnState();
  }
}

class _BSColumnState extends BSColumnState<BSColumn> {
  final String _regExpression =
      r"(^col$)|(^col-)(([0-9]|([1-9][0-2]))|((sm)|(md)|(lg)|(xl)|(xxl))-([0-9]|([1-9][0-2])))$";

  @override
  void initState() {
    super.initState();
    RegExp regExp = RegExp(
      _regExpression,
      caseSensitive: false,
      multiLine: false,
      dotAll: false,
    );

    // ensure that passed breakpoints are valid
    for (int i = 0; i < widget.breakPointTriggers.length; i++) {
      if (regExp.firstMatch(widget.breakPointTriggers[i]) == null) {
        throw FormatException(
            "Must pass valid break point triggers only. Ex: 'col', 'col-0', 'col-12', 'col-xxl-6'.\nMust match the reg expression (case sensitive):\n$_regExpression\nPassed Value: ${widget.breakPointTriggers[i]}");
      }
    }
  }

  /// returns set breakpoint triggers
  List<String> getBreakPointTriggers() {
    return widget.breakPointTriggers;
  }

  @override
  Widget build(BuildContext context) {
    double maxWidth = BSContainerWrapper.of(context).width;
    double width = BSBreakPoints.columnWidthFromBreakPointTriggers(
      maxWidth: maxWidth,
      screenWidth: MediaQuery.of(context).size.width,
      breakPointTriggers: widget.breakPointTriggers,
    );

    return SizedBox(
      width: width,
      height: widget.height,
      child: Column(
        crossAxisAlignment: widget.crossAxisAlignment,
        mainAxisAlignment: widget.mainAxisAlignment,
        mainAxisSize: widget.mainAxisSize,
        textDirection: widget.textDirection,
        textBaseline: widget.textBaseline,
        verticalDirection: widget.verticalDirection,
        children: widget.children,
      ),
    );
  }
}
